#
# spec file for package yast2-sound
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           yast2-sound
Version:        4.3.3
Release:        1.117
Summary:        YaST2 - Sound Configuration
License:        GPL-2.0-or-later
Group:          System/YaST
URL:            https://github.com/yast/yast-sound

Source0:        %{name}-%{version}.tar.bz2

BuildRequires:  alsa-devel
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  perl-XML-Writer
BuildRequires:  ruby
BuildRequires:  update-desktop-files
BuildRequires:  yast2
BuildRequires:  yast2-core-devel
BuildRequires:  yast2-devtools >= 4.2.2
BuildRequires:  yast2-testsuite

# workaround for OS builds, see jsc#SLE-11862
%ifnarch i586
BuildRequires:  kernel-default
%endif

# Fixed handling of Kernel modules loaded on boot
Requires:       alsa
# For proc_modules.scr
Requires:       yast2 >= 3.1.180
Requires:       yast2-ruby-bindings >= 1.0.0

Obsoletes:      yast2-sound-devel-doc

Supplements:    autoyast(sound)

%description
This package contains the YaST2 component for sound card configuration.

%prep
%setup -n %{name}-%{version}

%build
%yast_build

%install
%yast_install
rm -rf %{buildroot}/%{yast_plugindir}/libpy2ag_audio.la
%yast_metainfo

%post
# rename the config file to the new modprobe schema
if test -e /etc/modprobe.d/sound; then
    mv -f /etc/modprobe.d/sound /etc/modprobe.d/50-sound.conf
fi

%files
%{yast_yncludedir}
%{yast_clientdir}
%{yast_desktopdir}
%{yast_metainfodir}
%{yast_ybindir}
%{yast_moduledir}
%{yast_schemadir}
# database
%{yast_ydatadir}
# agents
%{yast_plugindir}
%{yast_scrconfdir}
%{yast_icondir}
%doc %{yast_docdir}
%license COPYING

%changelog
* Mon Aug 10 2020 schubi@suse.de
- AutoYaST: Added supplements: autoyast(sound) into the spec file
  in order to install this packages if the section has been defined
  in the AY configuration file (bsc#1146494).
- 4.3.3
* Thu Jul  9 2020 bwiedemann@suse.com
- Only record the first 2 numbers of kernel version (boo#1173918)
- 4.3.2
* Tue May 12 2020 jreidinger@suse.com
- Autoyast schema: Allow optional types for string and map objects
  (bsc#1170886)
- 4.3.1
* Tue May  5 2020 mfilka@suse.com
  bnc#1170224
  - fixed sound card database creation
  - patch by lpechacek@suse.com
- 4.3.0
* Wed Apr 29 2020 jsrain@suse.com
- avoid attempts to build sound card database if no kernel
  available (related to jsc#SLE-11862)
- 4.2.4
* Thu Apr 16 2020 mfilka@suse.com
- jsc#SLE-11862
  - dropped conditional build to unify SLE and OS builds
- 4.2.3
* Tue Aug 27 2019 schubi@suse.de
- Set X-SuSE-YaST-AutoInstResource in desktop file (bsc#144894).
- 4.2.2
* Tue Jul  9 2019 lslezak@suse.cz
- Restore back a SLE workaround (disable on 32-bit archs)
  (related to the previous fix fate#319035)
- 4.2.1
* Fri May 31 2019 hellcp@mailbox.org
- Add metainfo (fate#319035)
- Revamp spec
- Replace GenericName with Comment
- 4.2.0
* Tue Dec 18 2018 jreidinger@suse.com
- always use absolute path to binaries (bsc#1118291)
- properly escape shell arguments (bsc#1118291)
- 4.1.1
* Wed Dec 12 2018 jlopez@suse.com
- Hardening commands execution (part of bsc#1118291).
- Replace backticks by Yast::Execute.
- 4.1.0
* Mon Nov 26 2018 noahadvs@gmail.com
- Provide icon with module (boo#1109310)
- 4.0.2
* Wed Aug 22 2018 schubi@suse.de
- Switched license in spec file from SPDX2 to SPDX3 format.
* Tue Aug 21 2018 schubi@suse.de
- Changed dir of COPYING file.
* Thu Jun 28 2018 schubi@suse.de
- Added additional searchkeys to desktop file (fate#321043).
- 4.0.1
* Fri Apr  6 2018 mfilka@suse.com
- bnc#1087957 - version bump
- 4.0.0
* Wed Jun  1 2016 igonzalezsosa@suse.com
- Drop yast2-sound-devel-doc package (fate#320356)
- 3.1.10
* Wed Mar 23 2016 cwh@suse.com
- Fixed dependency on yast2 version that contains .proc.modules
  agent (bsc#972310)
- Fixed regexp to respect changed output of modprobe (bsc#972315)
- 3.1.9
* Wed Oct  7 2015 lslezak@suse.cz
- do not check for %%suse_version == 1315, the existing check for
  %%is_opensuse is sufficient (bsc#949046)
- 3.1.8
* Fri Sep 18 2015 dimstar@opensuse.org
- Enable build for Leap 42.1 (boo#945037).
* Wed Jan 28 2015 lslezak@suse.cz
- do not set any icon in Confirm.Detection() call
- 3.1.7
* Thu Dec 18 2014 lslezak@suse.cz
- fixed bashism in "alsadrivers" script (authored by "Ledest")
- 3.1.6
* Thu Dec  4 2014 jreidinger@suse.com
- remove X-KDE-Library from desktop file (bnc#899104)
* Fri Feb 28 2014 jreidinger@suse.com
- Drop joystick for sound card ports as it is dropped also in
  alsa (BNC#865350)
- improve excludearch to be only for SLE-12 as opensuse stil builds
  working x86
- 3.1.4
* Wed Jan 29 2014 ro@suse.de
- set excludearch for i586 and s390 as SLE-12 does not build a
  runnable kernel there
* Wed Nov 20 2013 lslezak@suse.cz
- removed automatic 2nd stage support (the 2nd stage has been
  dropped completely) (FATE#314695)
- 3.1.3
* Fri Nov  8 2013 locilka@suse.com
- Using unified API for handling Kernel modules to be loaded
  on boot (bnc#838185)
- 3.1.2
* Wed Nov  6 2013 lslezak@suse.cz
- display only 3 columns in the volume dialog to make the window
  narrower (bnc#848706)
- 3.1.1
* Thu Oct 17 2013 lslezak@suse.cz
- do not crash during sound card removal (bnc#845928)
  (workaround for Ops.is() not working properly with typed maps
  and arrays)
* Thu Sep 19 2013 lslezak@suse.cz
- do not use *.spec.in template, use *.spec file with RPM macros
  instead
- 3.1.0
* Tue Sep  3 2013 lslezak@suse.cz
- added AudioScience cards to the manual card selection
  (bnc#832097, fate#310119)
- 3.0.2
* Wed Aug  7 2013 lslezak@suse.cz
- generate the sound card database in YAML format (instead of
  obsolete YCP), use YAML data files
- 3.0.1
* Wed Jul 31 2013 yast-devel@opensuse.org
- converted from YCP to Ruby by YCP Killer
  (https://github.com/yast/ycp-killer)
- version 3.0.0
* Thu Jul 25 2013 lslezak@suse.cz
- documentation update
- move development documentation to devel-doc subpackage
- resolved gcc and doxygen warnings
- 2.24.0
* Thu Apr 26 2012 lslezak@suse.cz
- 2.22.1
* Wed Apr 25 2012 lslezak@suse.cz
- path to asound.state has been changed (now stored in /var/lib/alsa
  instead of /etc)
* Tue Apr 24 2012 lslezak@suse.cz
- reimplemented driver reloading ("rcalsasound reload" does not
  work with systemd) (bnc#751689)
* Thu Mar 29 2012 jsuchome@suse.cz
- merge proofread texts
* Tue Mar 20 2012 aschnell@suse.de
- fixed for gcc 4.7
- 2.22.0
* Fri Nov 25 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Oct 11 2011 lslezak@suse.cz
- added support for USB joysticks, redesigned the main dialog
  to support both USB and Gameport joysticks, updated the test
  dialog (use sliders, fixed button and axes detection)
  (bnc#695323)
- 2.21.3
* Thu Sep 29 2011 visnov@suse.cz
- set dialog title
- 2.21.2
* Fri Aug  5 2011 tgoettlicher@suse.de
- fixed .desktop file (bnc #681249)
* Mon Jul 25 2011 lslezak@suse.cz
- fixed detection of sound cards missing in the sound card database
  (bnc#706992)
- 2.21.1
* Fri Jul  8 2011 lslezak@suse.cz
- AudioScience (snd-asihpi) driver requires alsa-firmware package
- 2.21.0
* Mon Feb  7 2011 lslezak@suse.cz
- fixed mixer (volume setting) dialog - yast used the previous
  value for teh volume level so the value displayed in the UI and
  the actual volume setting were not in sync when moving the
  sliders (bnc#664094)
- 2.20.2
* Wed Jan  5 2011 lslezak@suse.cz
- enable PulseAudio also in KDE installations (bnc#662260)
- 2.20.1
* Tue Nov  9 2010 lslezak@suse.cz
- build the soundcard database during package build - use
  the existing ALSA drivers, the DB is always up to date
  and is architecture dependent now
- 2.20.0
* Thu Oct 14 2010 lslezak@suse.cz
- make the joystick dialog label better translatable in RTL
  languages (bnc#583209)
* Wed Jan 13 2010 kmachalkova@suse.cz
- Adjusted .desktop file(s) to wrap /sbin/yast2/ calls in xdg-su
  where root privileges are needed, removed X-KDE-SubstituteUID key
  (bnc#540627)
* Wed Dec 30 2009 lslezak@suse.cz
- fixed SoundBlaster X-Fi support (bnc#560163)
- 2.19.1
* Fri Nov 20 2009 lslezak@suse.cz
- unified usage of "SoundFont" term (bnc#548898)
- 2.19.0
* Wed Oct 14 2009 lslezak@suse.cz
- added X-Fi driver to the soundcard database (bnc#546440)
- 2.18.4
* Thu Oct  1 2009 lslezak@suse.cz
- convert all '_' to '-' in hwinfo driver name (bnc#290279)
- 2.18.3
* Mon Sep 21 2009 lslezak@suse.cz
- Disable PulseAudio in KDE installations (bnc#537784)
- 2.18.2
* Tue Jun 16 2009 mvidner@suse.cz
- Using autodocs-ycp.ami, which contains a fix for automake 1.11.
* Fri Apr 10 2009 lslezak@suse.cz
- convert /etc/modprobe.d/sound to /etc/modprobe.d/50-sound.conf
  during package update (bnc#485942)
- 2.18.1
* Tue Mar 31 2009 lslezak@suse.cz
- convert Autoyast volume settings to the expected format
* Tue Mar 31 2009 lslezak@suse.cz
- improved logging in alsa-agent when a requested volume
  setting failed due to an unsupported operation
  (e.g. missing mute switch)
* Thu Mar 26 2009 lslezak@suse.cz
- Use /etc/modprobe.d/50-sound.conf config file instead of
  /etc/modprobe.d/sound (bnc#485942)
* Thu Feb 26 2009 lslezak@suse.cz
- set 100%% volume for snd-hda-intel driver (bnc#477853),
  (bnc#466428)
* Wed Jan 28 2009 lslezak@suse.cz
- do not restore volume settings at start up (bnc#466456)
* Tue Jan 13 2009 lslezak@suse.cz
- 2.18.0
* Fri Jan  9 2009 lslezak@suse.cz
- fixed snd slots option for snd-aoa driver (PPC) (bnc#460338)
* Fri Jan  9 2009 lslezak@suse.cz
- make channel names unique - add channel index to channel name
  if more channels have the same name, fixes UI syntax error
  for some sound cards (bnc#407060)
* Fri Dec 19 2008 lslezak@suse.cz
- removed the progress dialog at start up (bnc#447573)
- abort immediately when there is no change (bnc#458317)
- sound, joystick - hide the Back button in the overview dialog
  (bnc#440561, bnc#440559)
- allow entering only ASCII characters in the kernel module options
  dialog (bnc#447018)
* Thu Dec 18 2008 ro@suse.de
- fix build for non-alsa case (s390)
* Tue Dec  2 2008 lslezak@suse.cz
- fixed package installation in autoyast installation mode
  (bnc#450416)
- 2.17.13
* Tue Nov 25 2008 lslezak@suse.cz
- fixed "Really Abort" popup behavior in the "Add" dialog
  (bnc#447408)
- 2.17.12
* Wed Nov 19 2008 lslezak@suse.cz
- unset $ALSA_CONFIG_PATH when playing the test sound - do not
  use the pulseaudio plugin, the PA daemon might not be running
  (bnc#440981)
- 2.17.11
* Thu Nov 13 2008 ug@suse.de
- rnc file fixed
* Mon Nov 10 2008 lslezak@suse.cz
- updated the soundcard DB to kernel 2.6.27.4-2 (bnc#443713)
- 2.17.10
* Thu Oct 23 2008 lslezak@suse.cz
- fixed PulseAudio menu item (bnc#437256)
- 2.17.9
* Mon Oct 13 2008 locilka@suse.cz
- Fixed help text (bnc#430521).
- 2.17.8
* Wed Oct  8 2008 lslezak@suse.cz
- Install additional packages automatically when
  'Automatic Configuration' was selected in the first stage
  (bnc#433046)
- 2.17.7
* Tue Oct  7 2008 lslezak@suse.cz
- use 'setup-pulseaudio' script for configuring PulseAudio
  (bnc#425475)
- 2.17.6
* Mon Oct  6 2008 lslezak@suse.cz
- fixed storing additional module parameters (bnc#404900)
  (check the key before removal from a map)
- 2.17.5
* Mon Oct  6 2008 lslezak@suse.cz
- the sound card DB has been updated to kernel-2.6.27-rc7-12
  (bnc#432575)
- 2.17.4
* Mon Oct  6 2008 visnov@suse.cz
- adapt to new Confirm::Detection API (bnc #431276)
* Fri Sep 12 2008 lslezak@suse.cz
- fixed build - added missing PulseAudio.* files in .spec file
- 2.17.3
* Thu Sep 11 2008 lslezak@suse.cz
- PulseAudio support in UI (Other->PulseAudio Configuration)
  (fate#304936), (UI only, the setting is not saved/activated yet)
- 2.17.2
* Wed Sep 10 2008 lslezak@suse.cz
- merged proofread texts (2008-09-08)
- 2.17.1
* Tue Aug 19 2008 sschober@suse.de
- rnc file fixed for autoyast
* Mon Jun 16 2008 lslezak@suse.cz
- use OK/Cancel buttons in the main dialog (bnc#398485, bnc#398489)
- 2.17.0
* Fri May 23 2008 lslezak@suse.cz
- set also volume of "Speaker" channel (bnc#330409)
- 2.16.11
* Fri May 16 2008 jsrain@suse.cz
- added categories Settings and System into desktop file
  (bnc #382778)
* Wed Apr 30 2008 lslezak@suse.cz
- save non-PCI and non-USB sound cards to MODULES_LOADED_ON_BOOT
  sysconfig variable (bnc#331659)
- remove empty 'options snd' config line when there is no sound
  card configured
- 2.16.10
* Fri Apr 25 2008 lslezak@suse.cz
- do not write 'index' option, write 'slots' option of 'snd' driver
  to define the order of the configured soundcards (bnc#381695)
- 2.16.9
* Mon Apr 14 2008 lslezak@suse.cz
- updated the sound card database, added "snd-oxygen" driver to
  the database
- 2.16.8
* Wed Apr  9 2008 lslezak@suse.cz
- variable 'sublist' renamed ('sublist' is going to be a new
  builtin function)
- 2.16.7
* Tue Apr  8 2008 lslezak@suse.cz
- package the files needed for regenerating the sound card database
  into the source tarball
- 2.16.6
* Fri Apr  4 2008 locilka@suse.cz
- Enhanced user-feedback during automatic configuration.
- Adjusted RPM dependencies.
- 2.16.5
* Fri Mar 28 2008 ug@suse.de
- autoyast rnc file fixed
* Mon Mar 17 2008 lslezak@suse.cz
- unified button labels (use "OK" instead of "Accept")
  (fate#120373)
- updated sound card database (kernel 2.6.24.1)
- 2.16.4
* Mon Mar 17 2008 jsrain@suse.cz
- added 'StartupNotify=true' to the desktop file (bnc #304964)
* Mon Feb 25 2008 lslezak@suse.cz
- automatically update list of the cards for the current vendor
  (#31772)
- use UI::ChangeWidget() instead of UI::ReplaceWidget()
- fixed missing symbols in audio agent
- 2.16.3
* Tue Jan  8 2008 lslezak@suse.cz
- fixed installation proposal ('nil' summary) (#346792)
- 2.16.2
* Mon Dec 10 2007 lslezak@suse.cz
- merged proofread texts (2007-18-23)
* Fri Oct 26 2007 lslezak@suse.cz
- fixed build problem (unpackaged alsa_packages.ycp file)
- 2.16.1
* Fri Oct 26 2007 lslezak@suse.cz
- added package DB, install packages required by the configured
  driver (#329690)
- 2.16.0
* Thu Aug 30 2007 lslezak@suse.cz
- support for PS3 sound card (automatic configuration) (#305927)
- updated sound card DB
- 2.15.11
* Tue Aug 14 2007 lslezak@suse.cz
- don't read/write hwcfg files (#290430)
- updated .rnc schema file (#253614)
- updated sound card DB
- 2.15.10
* Tue Jul 31 2007 lslezak@suse.cz
- use 'Apple PowerPC' for all PowerPC models (#295616)
- updated sound card DB
- fixed formatting error message in audio-agent
- 2.15.9
* Wed Jun  6 2007 lslezak@suse.cz
- removed empty index.html file
- check existence of the files (#256442)
- use [Accept] button instead of [Finish] in the main dialog
  during installation (#270519)
- 2.15.8
* Fri May 25 2007 jsrain@suse.cz
- removed outdated translations from .desktop-files (#271209)
* Thu May 24 2007 lslezak@suse.cz
- added minimal commandline mode support to 'joystick' (#269895)
- 2.15.7
* Fri Apr 27 2007 lslezak@suse.cz
- translate "iSpeaker" and "Front" channel names (#252595)
- 2.15.6
* Mon Mar 26 2007 lslezak@suse.cz
- set "iSpeaker" channel volume (#251844)
- 2.15.5
* Wed Feb 21 2007 lslezak@suse.cz
- added "Play Test Sound" item to the main menu (#244905)
- 2.15.4
* Mon Feb 12 2007 lslezak@suse.cz
- use the driver provided by hwinfo if the card is not in the yast
  sound card DB (#105754)
- 2.15.3
* Mon Jan 29 2007 lslezak@suse.cz
- use snd-aoa driver on PPC with layout-id property (#217300)
- updated soundcard DB
- 2.15.2
* Wed Jan 17 2007 lslezak@suse.cz
- sound_auto.ycp - use Progress::set()
- sort the cards by index in the overview dialog
* Wed Jan 17 2007 lslezak@suse.cz
- remove the options for unused modules from /etc/modprobe.d/sound
  file (#164704)
- 2.15.1
* Wed Dec  6 2006 lslezak@suse.cz
- updated RNC file to match the new export format (#219399)
* Thu Nov 30 2006 lslezak@suse.cz
- align action buttons to the left in the advanced dialog (#211557)
- display "Index" in the table header (#211555)
- enahced description of "Start Sequencer" option (#211559)
- display kernel module name in driver list
- use sliders in the mixer dialog, display [OK] button (#211563)
- added type information, fixed type mismatch (#115256)
- correctly export volume settings in autoyast (#219399)
- volume export/import testsuite
- fixed volume configuration in autoyast (config mode)
- 2.15.0
* Fri Nov 10 2006 lslezak@suse.cz
- added a RNC schema for Autoyast profile validation (#219011)
- 2.14.0
* Mon Oct 23 2006 lslezak@suse.cz
- help text - added 'aoss' wrapper description (fate #300351,
  bug #117806)
- 2.13.16
* Thu Sep 21 2006 lslezak@suse.cz
- new option - select the primary sound card (fate #300352)
- updated the sound card DB
- 2.13.15
* Thu Sep 14 2006 lslezak@suse.cz
- use Progress::set() instead of Progress::on()/off()
- 2.13.14
* Thu Sep 14 2006 ro@suse.de
- added yast2-core-devel to BuildRequires
* Tue Aug 29 2006 lslezak@suse.cz
- properly compute index of the selected card - fixed problem
  with more sound cards (#177962)
- fixed abort when an internal error occurrs (#201337)
- fixed static hwcfg file and unique key handling for non-PCI
  sound devices(#202086)
- use the default values for kernel module options instead of
  empty string (option=,,1 is not valid)
- don't try to set volume if there is no sound card configured
- fixed button label in the help text (#201127)
- .spec file: don't pack libpy2ag_audio.la file
- 2.13.13
* Mon Jul 17 2006 lslezak@suse.cz
- expert dialog - use standard Add/Edit/Delete buttons in the
  dialog, allow to add a driver option which is not in the yast
  sound card database (#128054), changed layout of the dialog
- close volume dialog by WM (X button in the title) (#148687)
- fixed CD device detection in sound font installation
  code (#171060)
- fixed sound card DB generator: read all tags from
  alsa-module-syntax file, properly mark texts for translation,
  replace modinfo text by proofread message if it's available,
  updated documentation
- updated the sound card DB
- 2.13.12
* Thu May  4 2006 lslezak@suse.cz
- read_routines.ycp - added textdomain
- 2.13.11
* Thu May  4 2006 lslezak@suse.cz
- merged proofread texts
- 2.13.10
* Thu Mar  9 2006 lslezak@suse.cz
- merged proofread texts
- 2.13.9
* Mon Feb 20 2006 lslezak@suse.cz
- updated BuildRequires (replaced yast2-devel-packages macro)
- 2.13.8
* Tue Jan 31 2006 lslezak@suse.cz
- updated the sound card database
- 2.13.7
* Wed Jan 25 2006 lslezak@suse.cz
- updated the sound card database
- 2.13.6
* Mon Jan  9 2006 lslezak@suse.cz
- use Package:: module (Require:: is obsoleted)
- 2.13.5
* Fri Jan  6 2006 lslezak@suse.cz
- properly skip sound card detection in the manual mode (#137908)
- 2.13.4
* Wed Jan  4 2006 lslezak@suse.cz
- improved module loading test
- 2.13.3
* Mon Dec 19 2005 jsuchome@suse.cz
- merged proofread texts
- 2.13.2
* Wed Nov 16 2005 lslezak@suse.cz
- save configuration to hwcfg-vpid-* file which is independent
  on card location (slot number) (#128629)
- wait after module loading before sound card check (#96965)
- added IO address 0x538 for opl3sa2 module to the option list
  (#132504)
- 2.13.1
* Tue Sep 27 2005 lslezak@suse.cz
- remove cards before writing configured cards (#116483)
- version 2.13.0
* Fri Aug 19 2005 lslezak@suse.cz
- mixer - initialize also "Front", "Headphone" and "Master Mono"
  channels (#105486)
- 2.12.9
* Mon Aug 15 2005 lslezak@suse.cz
- merged proofread texts
- 2.12.8
* Fri Aug 12 2005 lslezak@suse.cz
- updated sound card database (for kernel 2.6.13-rc6) (#104324)
- enable Abort button in the error dialog (#102534)
- 2.12.7
* Wed Aug 10 2005 lslezak@suse.cz
- properly initialize mixer during installation (#102663)
- use title style capitalization in dialog headers
- 2.12.6
* Fri Aug  5 2005 lslezak@suse.cz
- use new alsasound initscript commands (unload/reload)
- 2.12.5
* Thu Aug  4 2005 lslezak@suse.cz
- merged proofread texts
- 2.12.4
* Tue Aug  2 2005 lslezak@suse.cz
- use WizardHW module for the first dialog
- removed obsolete dialogs
- workflow and help texts adapted
- assign unique ID for virtual or manually configured cards
- assign bus ID to configured cards
- 2.12.3
* Thu Jul 28 2005 lslezak@suse.cz
- updated desktop files
- 2.12.2
* Wed May  4 2005 lslezak@suse.cz
- renamed variables 'default'
- 2.12.1
* Thu Apr 28 2005 lslezak@suse.cz
- properly initialize mixer settings (#61709)
- 2.12.0
* Wed Mar 23 2005 lslezak@suse.cz
- hwcfg-static file (for ISA cards) search fixed - don't overwrite
  already existing config for another device (#74266)
- really skip sound card detection in manual mode (#74361)
- 2.11.10
* Wed Mar 16 2005 lslezak@suse.cz
- adjust also volume of "Front" channel (#72971)
- 2.11.9
* Thu Mar 10 2005 lslezak@suse.cz
- use 'default' PCM device for playing test sound
  (instead of 'plughw' device) (#71022)
- 2.11.8
* Mon Mar  7 2005 lslezak@suse.cz
- create sysconfig hwcfg file
- 2.11.7
* Wed Mar  2 2005 lslezak@suse.cz
- merged proofread texts
- 2.11.6
* Tue Feb 22 2005 lslezak@suse.cz
- sound card database update (#63457)
- 2.11.5
* Mon Feb  7 2005 lslezak@suse.cz
- merged proofread texts
- version 2.11.4
* Mon Nov 22 2004 lslezak@suse.cz
- select&lookup were replaced by bracket operator
- version 2.11.3
* Thu Nov 18 2004 lslezak@suse.cz
- use bracket operator instead of lookup&select
- version 2.11.2
* Wed Oct 27 2004 lslezak@suse.cz
- adapted to new Mode:: API
- version 2.11.1
* Wed Oct 13 2004 lslezak@suse.cz
- set volume of Master Mono channel (#46555)
- translate channel names in the mixer dialog (#30177)
- version 2.11.0
* Mon Oct 11 2004 jsrain@suse.cz
- adapted to new Arch:: interface
* Mon Sep 27 2004 lslezak@suse.cz
- version 2.10.6
* Fri Sep 24 2004 jsuchome@suse.cz
- do not save modules options with default value (#45646)
- updated sound card database (#45646)
* Tue Sep 14 2004 lslezak@suse.cz
- autoyast fixes - sound card status is always "not running",
  Get/SetModified functions, fixed initialization
- version 2.10.5
* Fri Sep 10 2004 lslezak@suse.cz
- check also kernel joystick modules (#44394)
- version 2.10.4
* Thu Sep  9 2004 lslezak@suse.cz
- install all required kernel modules/packages (#44394)
- version 2.10.3
* Tue Aug 10 2004 jsuchome@suse.cz
- merged proofread texts
* Wed Jul 28 2004 lslezak@suse.cz
- joystick package has been renamed to input-utils (#43297)
- version 2.10.2
* Mon Jun 28 2004 jsuchome@suse.cz
- fixed build (docu dependencies), fixed paths for sound drivers
- 2.10.1
* Mon Jun 14 2004 jsuchome@suse.cz
- removed testing for parameters prefix (snd_*)
* Fri Jun 11 2004 jsuchome@suse.cz
- new command line actions : set, channels, volume
- corrected check for module option values
- 2.10.0
* Tue May 18 2004 jsuchome@suse.cz
- fixed script for copying sound fonts (#40663)
- 2.9.22
* Tue May 11 2004 jsuchome@suse.cz
- during write, initialize mixer before setting volumes (#38797)
- 2.9.21
* Tue May  4 2004 jsuchome@suse.cz
- merged in proofread text
* Thu Apr 29 2004 jsuchome@suse.cz
- fix: do not set Mode::config during autoinstallation
* Thu Apr 22 2004 jsuchome@suse.cz
- match cards added during autoinstalltion config with detected ones (#38797)
- correctly handle Imported volume settings
- 2.9.20
* Mon Apr  5 2004 jsuchome@suse.cz
- fix of audio agent: close opened mixer handle
  (#38040: bug causes fall of whole YaST in some situations)
- 2.9.19
* Fri Apr  2 2004 jsuchome@suse.cz
- changed license to GPL
- 2.9.18
* Mon Mar 29 2004 jsuchome@suse.cz
- fix of sound card database (tiwai)
- fix of testsuites: check only Sound module related files
- 2.9.17
* Fri Mar 26 2004 jsuchome@suse.cz
- fixed joystick options in sound car database (tiwai)
* Fri Mar 26 2004 jsuchome@suse.cz
- fix of volume dialog (#36980)
- joystick configuration: now update also sound module options (#36994)
- 2.9.16
* Tue Mar 23 2004 jsuchome@suse.cz
- correctly grab option values from the table (#36690)
* Mon Mar 22 2004 jsuchome@suse.cz
- 2.9.15
* Fri Mar 19 2004 mvidner@suse.cz
- added AGENT_LIBADD so that agents work from standalone Perl
* Wed Mar 17 2004 jsuchome@suse.cz
- fix of joystick test: look to correct device
* Wed Mar 17 2004 jsuchome@suse.cz
- fix: correstly switch the lists with vendors/modules
  (caused by SelectionBox behaviour)
- do not set default module parameters ("enable", "index") if module
  doens't support them
- 2.9.14
* Mon Mar 15 2004 jsuchome@suse.cz
- fixed sound card database (tiwai):
  the default parameter values of es1968 options.  (bug #29759)
* Fri Mar 12 2004 jsuchome@suse.cz
- remove old module options from /etc/modprobe.conf
- do not write unnecessary lines (#35710)
* Thu Mar 11 2004 jsuchome@suse.cz
- remove sound configuration from /etc/modprobe.conf, when it was
  written to /etc/modprobe.d/sound
- 2.9.13
* Wed Mar 10 2004 sh@suse.de
- V 2.9.12
- Migration to new wizard
* Tue Mar  9 2004 jsuchome@suse.cz
- updated card database (tiwai)
- fix of return value from main sequence (#35480)
* Mon Mar  8 2004 jsuchome@suse.cz
- more type fixes
- set desktop icon
- 2.9.11
* Mon Mar  1 2004 jsuchome@suse.cz
- configuration now stored in /etc/modprobe.d/sound (new agent)
- type fixes
- use Sequencer module
- 2.9.10
* Mon Mar  1 2004 jsuchome@suse.cz
- more strict typing (lists, map)
* Mon Mar  1 2004 jsuchome@suse.cz
- merged texts from proofread
* Fri Feb 27 2004 jsuchome@suse.cz
- sound card database: fixed module parameters descriptions (tiwai)
* Thu Feb 26 2004 jsuchome@suse.cz
- hack for CS4236 on IBM Thinkpad 600E (#34462)
- 2.9.9
* Thu Feb 26 2004 jsuchome@suse.cz
- removed testsound (it was too big)
* Mon Feb 23 2004 jsuchome@suse.cz
- new card database for kernel 2.6 (tiwai@suse.de)
- 2.9.8
* Thu Feb 19 2004 mvidner@suse.cz
- changed sort to use "<" instead of "<=" because of the switch to std::sort
* Sun Feb  8 2004 arvin@suse.de
- removed config files (*.y2cc)
* Mon Feb  2 2004 jsuchome@suse.cz
- fixed testsuite
- removed hwinfo from needforbuild
- 2.9.6
* Tue Dec  9 2003 jsuchome@suse.cz
- SCR agents adapted for new interpreter
* Fri Dec  5 2003 jsuchome@suse.cz
- Manual dialog: possibility to choose a card both by kernel and vendor
* Mon Dec  1 2003 jsuchome@suse.cz
- syntax fixes for new interpreter
- move most functions from alsa_routines.ycp and oss_routines.ycp to
  routines.ycp and created new file volume_routines.ycp
- 2.9.5
* Mon Nov 24 2003 jsuchome@suse.cz
- correctly initialize variables during installation proposal
  (the call of Sound::ForceReset() is back)
* Tue Nov 18 2003 jsuchome@suse.cz
- fixed button label in helptext (#33076)
- migrated to doxygen
- 2.9.4
* Fri Nov  7 2003 jsuchome@suse.cz
- basic command-line interface
- large code cleanup (removed unused parts, corrected comments, etc.)
- 2.9.3
* Mon Oct 27 2003 jsuchome@suse.cz
- fix: parameter names checked (for 'snd_' prefix) before writing (#32632)
* Fri Oct 24 2003 jsuchome@suse.cz
- initial support for two types of module parameters naming (#32632)
- fix: reseting values of parameters to defaults
- fix: check the possible values of parameters
- 2.9.2
* Tue Oct 21 2003 jsuchome@suse.cz
- dialog with sound cards has list of vendors now (#11024)
- new items in card database (map vendor->models)
- 2.9.1
* Tue Oct  7 2003 jsuchome@suse.cz
- autoinstallation: changed variables to current behaviour (#31117: use
  Mode::config or Sound::write_only instead of Sound::autoinstallation)
- 2.9.0
* Thu Sep 18 2003 jsuchome@suse.cz
- joystick fix: widgets ID's were translated which caused the test
  dialog not to work (#31295)
- 2.8.10
* Tue Sep 16 2003 jsuchome@suse.cz
- check for nil values to prevent error messages in log
- 2.8.9
* Fri Sep 12 2003 jsuchome@suse.cz
- check the return code of alsaconf (#30594)
- 2.8.8
* Mon Sep  8 2003 jsuchome@suse.cz
- do not remove volume settings when there are not set
* Fri Sep  5 2003 jsuchome@suse.cz
- merged in proofread texts
- 2.8.7
* Fri Aug 29 2003 jsuchome@suse.cz
- fixed sound card database entry
* Thu Aug 28 2003 jsuchome@suse.cz
- confirm hardware detection in manual mode (#26515)
* Tue Aug 26 2003 jsuchome@suse.cz
- do not return `finish during installation
- 2.8.6
* Wed Aug 20 2003 jsuchome@suse.de
- removed redundant "initialization dialog" (#28779)
- 2.8.5
* Thu Aug 14 2003 jsuchome@suse.de
- removed SuccessDialog (#28774)
- 2.8.4
* Mon Aug 11 2003 jsuchome@suse.de
- proofread texts, 1st round
- 2.8.3
* Wed Aug  6 2003 jsuchome@suse.de
- remebered cards table focus (bug #28058)
* Mon Aug  4 2003 jsuchome@suse.de
- fixed testsuite, added hwinfo to needforbuild
- fixed typo in Makefile
* Mon Aug  4 2003 jsuchome@suse.de
- updated sound card database (takashi@suse.de)
- 2.8.2
* Thu Jul 10 2003 jsuchome@suse.de
- used Label and Popup interface
* Thu May 22 2003 jsuchome@suse.cz
- fixed: mixed volume settings after removing and adding first card
  while there is present another one
* Mon May 12 2003 jsuchome@suse.de
- probe old ISA cards with alsaconf (#25285)
- added Progress steps to Read function
- 2.8.1
* Thu Mar 20 2003 jsuchome@suse.de
- adapted to Require interface
- changed helptext in joystick dialog (#25035)
- 2.8.0
* Tue Mar 11 2003 jsuchome@suse.de
- removed calling of agent for /var/lib/yast/unique
- rebuild needed witch correct tarball (#25064)
* Mon Mar 10 2003 jsuchome@suse.de
- tiwai@suse.de:
- added ICH5 support.
- fixed HDSP description.
* Tue Mar  4 2003 nashif@suse.de
- fixed testsuite
* Mon Mar  3 2003 jsuchome@suse.de
- merged proofreaded texts
* Fri Feb 21 2003 jsuchome@suse.de
- fixes: stderr of some commands (echo, aplay) goes to /dev/null,
    do not start joystick when not present (#23807)
* Fri Feb 14 2003 jsuchome@suse.de
- fixed argument for aplay (#23633)
* Tue Feb 11 2003 arvin@suse.de
- fixed testsuite
* Mon Feb 10 2003 jsuchome@suse.de
- proofreaded texts: 3rd round
* Mon Feb  3 2003 jsuchome@suse.cz
- added zero values (#19602) up to sound-slot/service 3
* Wed Jan 29 2003 jsuchome@suse.cz
- merged proofreaded texts
- 2.7.2
* Fri Jan 17 2003 jsuchome@suse.de
- added ncurses f-keys shortcuts
* Fri Jan 10 2003 jsuchome@suse.de
- fixed testsuite (imported module Arch has some SCR calls)
* Thu Jan  9 2003 jsuchome@suse.de
- fix of helptext (#19729 - "start ALSA")
- fix of #19602 - setting sound-slot-[01] and sound-service-[01]-0
  to "off" if card not present
* Fri Dec 13 2002 jsuchome@suse.de
- updated for new modules agent interface
- 2.7.1
* Fri Oct 25 2002 jsuchome@suse.cz
- dialog for joystick testing (works with the new version of jstest)
- enables also test when more joysticks are connected
- version 2.7.0
* Wed Oct  9 2002 lslezak@suse.cz
- enable/disable alsasound service depending on number of
  configured sound cards (#20464)
- version 2.6.25
* Tue Oct  1 2002 lslezak@suse.cz
- added missing textdomain in Sound module
- version 2.6.24
* Tue Sep 17 2002 lslezak@suse.de
- updated sound card DB - module snd-dt0197h renamed to snd-dt019x,
  added PPC integrated card ids (#19647), regenerated for 2.4.19 kernel
- fixed DB generator (add extra ids, default values)
- version 2.6.23
* Tue Sep 10 2002 lslezak@suse.cz
- provide/obsolete package y2c_sprc
- added missing include (#19283)
- version 2.6.22
* Mon Sep  9 2002 lslezak@suse.cz
- restart sound system after sound font installation (#19197)
- version 2.6.21
* Fri Sep  6 2002 lslezak@suse.cz
- fixed OSS mode starting
- provide/obsolete old packages
- version 2.6.20
* Wed Sep  4 2002 lslezak@suse.cz
- fixed copyfonts script (#18866) - allow spaces and tabs
  as separators in /etc/fstab
- version 2.6.19
* Mon Sep  2 2002 lslezak@suse.cz
- use module Directory
- version 2.6.18
* Tue Aug 27 2002 jsuchome@suse.cz
- provide/obsolete old translation packages
* Mon Aug 26 2002 lslezak@suse.cz
- use new joystick icon in y2cc
- version 2.6.17
* Fri Aug 23 2002 lslezak@suse.cz
- use 'model' and 'description' as card name if 'sub_vendor'
  and 'vendor' are empty (ISA card)
- version 2.6.16
* Wed Aug 14 2002 lslezak@suse.cz
- merged proofread texts
- version 2.6.15
* Wed Aug  7 2002 lslezak@suse.de
- added 3rd parameter to select() in sound DB generator
- fixed loading of joystick DB (changed to include file)
- version 2.6.14
* Mon Aug  5 2002 lslezak@suse.cz
- added alsa to Requires
- added help texts for translators
- updated sound DB
- version 2.6.13
* Wed Jul 31 2002 arvin@suse.de
- removed yast2-runlevel from neededforbuild and requires
* Mon Jul 22 2002 arvin@suse.de
- updated sound and joystick databases
* Mon Jul 22 2002 jsrain@suse.cz
- merged proofread texts
- version 2.6.10
* Fri Jul 19 2002 arvin@suse.de
- use correct path for sound card database
* Fri Jul 12 2002 arvin@suse.de
- use proper namespace for Args and CallFunction (#16776)
* Mon Jul  8 2002 mvidner@suse.cz
- Provides/Obsoletes also the devel subpackage
* Sun Jul  7 2002 arvin@suse.de
- moved non binary files to /usr/share/YaST2
* Mon Jul  1 2002 lslezak@suse.cz
- merged yast2 sound packages: yast2-agent-audio,
  yast2-config-sound, yast2-db-sound
- renamed to yast2-sound
- version 2.6.6
* Mon Jun 24 2002 lslezak@suse.cz
- fixed missing translation
- updated to automake-1.6.2
- version 2.6.5
* Tue May  7 2002 lslezak@suse.cz
- menu entries moved to config dir
- version 2.6.4
* Mon Apr 29 2002 lslezak@suse.cz
- allow joystick configuration even in quick mode
- removed unused code (.tmp.modules)
- fixed most of ycpdoc comments
- use /etc/init.d/* instead /usr/sbin/rc*
- write joystick model to sysconfig comment
- joystick.ycp - new YaST2 client
- removing joystick configuration is possible
- Sound:: added joystick related functions
- removed Start ALSA option in UI
- use LOAD_SEQUENCER in /etc/sysconfig/sound
- added joystick documentation
- test mode in joystick
- version 2.6.3
* Mon Apr 15 2002 lslezak@suse.cz
- update to automake 1.6.1
* Fri Apr 12 2002 lslezak@suse.cz
- update to automake 1.6
- version 2.6.1
* Wed Apr 10 2002 lslezak@suse.cz
- SuSE-8_0-Branch merged to the head
- spec file changes
- testsuite fixes
- added includes and imports
- version 2.6.0
* Wed Mar 27 2002 dmeszar@suse.cz
- fixed #15526 (start joystick in init only if there's a configured one)
* Thu Mar 21 2002 mvidner@suse.cz
- Fixed rcjoystick invocation. (#14957)
- 2.5.18
* Fri Mar 15 2002 dmeszar@suse.cz
- fixed #14590 (Sound re-configuration broken after update in some cases)
* Tue Mar 12 2002 dmeszar@suse.cz
- fixed #14876 (channels are not unmuted when configured via tv module
  on running system)
- fixed #14725 (abort confirmation when no changes were made)
* Wed Mar  6 2002 dmeszar@suse.cz
- fixed #14539 (infinite loop when setting option value to '')
- return empty map when aborted in autoyast (#14526)
* Wed Feb 27 2002 dmeszar@suse.cz
- fixed #13981 (exit the sound_write module when the proposal
  is empty (this applies only to proposal mode))
* Fri Feb 22 2002 dmeszar@suse.cz
- fixed #13601 (all volumes at zero after installation)
- screenshot mode implemented
- fixed proposing of nm256 soundcards
* Mon Feb 18 2002 dmeszar@suse.cz
- implemented joystick configuration
- adaptation for sound db changes (option description can be both
  string and list of strings)
* Mon Feb 11 2002 dmeszar@suse.cz
- speed improvements, proposal implemented
* Fri Feb  8 2002 lnussel@suse.de
- command line argument is of type string
* Mon Jan 28 2002 dmeszar@suse.cz
- fixed bug #12925 (config of single autodetected card not possible)
- added proposal_sound.ycp file
* Thu Jan 17 2002 dmeszar@suse.cz
- added joystick type selector dialog
* Mon Jan 14 2002 dmeszar@suse.cz
- fixed bug #11717 (restart modules after options had changed)
- moved /etc/sysconfig/alsa to /etc/sysconfig/sound
* Mon Jan  7 2002 dmeszar@suse.cz
- removed START_ALSA (moved to runlevel editor) and START_ALSA_SEQ
  (moved to /etc/sysconfig/alsa) variables.
- uses new sound database
* Tue Dec 18 2001 dmeszar@suse.cz
- Sound module implemented, third param for 'select'
* Fri Nov  9 2001 dmeszar@suse.cz
- use Wizard module, Wizard_hw module and other new libycp features
* Thu Oct  4 2001 dmeszar@suse.cz
- setting volume to 75%% for test sample for 'daca' cards (ppc)
  (bug #11339)
* Fri Sep 21 2001 dmeszar@suse.cz
- bug #7198 fixed (warning popup for nm256 sound cards
  not shown when the card is configured and module is
  launched again)
* Thu Sep 20 2001 dmeszar@suse.cz
- bug #10941 ('nil' shown as card label when uniq_id has changed
  after update)
- comment added for translators
* Tue Sep 18 2001 dmeszar@suse.cz
- corrected abort behaviour in complex dialog (#not reported)
  (when user pressed abort, module ended even if she pressed
  'no' in 'really abort' dialog)
* Mon Sep 17 2001 dmeszar@suse.cz
- bug #10750 fixed (don't save when nothing has changed)
* Mon Sep 17 2001 dmeszar@suse.cz
- bug #10639 fixed (Removing first sound card removes them all)
- bug #10529 (10662) fixed (YaST2 crashes: Undefined string operation?)
  resp. (sound/routines.ycp: strange lines)
* Mon Sep 10 2001 dmeszar@suse.cz
- use Arch:: instead of user_settings
* Tue Sep  4 2001 dmeszar@suse.cz
- use alias sound-slot-0 -> sound
  and	    sound -> char-major-14 for sparcs
* Tue Sep  4 2001 dmeszar@suse.cz
- unmute device "Wave Playback Volume" for ymf sound cards
- default value for lookup(3) added
* Fri Aug 31 2001 dmeszar@suse.cz
- bug #9993 fixed
- logs removed
* Wed Aug 29 2001 dmeszar@suse.cz
- fixed typos
- removed debug logging
* Mon Aug 27 2001 dmeszar@suse.cz
- use module name as alias 'char-major-14' on sparc
  instead of 'sound'
* Mon Aug 27 2001 dmeszar@suse.cz
- volume setting implemented for oss
* Wed Aug 22 2001 dmeszar@suse.cz
- oss support added, alpha version
- volume setting for oss not implemented so far
* Mon Aug 20 2001 dmeszar@suse.cz
- fixed shortcuts
* Mon Aug 20 2001 dmeszar@suse.cz
- bug #8335 fixed, options restoring when deleting card fixed
* Wed Aug 15 2001 dmeszar@suse.cz
- installation of one card much simplified
* Mon Aug 13 2001 dmeszar@suse.cz
- stderr of 'execute' commands redirected to /dev/null
  when running .target.bash
* Fri Aug 10 2001 dmeszar@suse.cz
- bug #5838 fixed
- minor code changes  UI(`fn()) -> UI::fn() SCR resp.
* Mon Jul 30 2001 dmeszar@suse.cz
- speed improvements
* Wed Jul 25 2001 dmeszar@suse.cz
- first dialog unified with printconf and tvconf modules
* Mon Jul 23 2001 dmeszar@suse.cz
- fixed 'requires' in rpm, workflow changes, option dialog improvements
* Tue May 15 2001 dmeszar@suse.cz
- doubled text fixed. when a new card is manually added, module description is
  used as a manufacturer name. (bug #8315, file routines.ycp).
- fixed bug in adding sound cards. (not reported)
  (files routines.ycp, sound_complex- list of all cards was compared
  against /var/lib/YaST/unique.inf, which was not correct. dialog
  with the choice "Add autodetected"/"Select from list" was not shown
  properly.  now it's compared
  with local copy of unique keys list. new parameter added to get_not_yet
  (function returning list of not configured soundcards))
- removed commented block of source code from 'sound_summary.ycp'
* Tue May 15 2001 dmeszar@suse.cz
- doubled text fixed. when a new card is manually added, module description is
  used as a manufacturer name. (bug #8315). fixed bug in adding sound cards. (not reported)
* Mon May 14 2001 dmeszar@suse.cz
- sound summary for non-pnp cards fixed (bug #8157)
* Fri May 11 2001 dmeszar@suse.cz
- soundblater awe card presence enhanced
* Thu May 10 2001 dmeszar@suse.cz
- fixed to work with new libhd (#7918)
* Mon May  7 2001 dmeszar@suse.cz
- module options fixed, card removing fixed
* Mon Apr 30 2001 dmeszar@suse.cz
- sound fonts loading enabled, abort dialog unified, summary spaces fixed
* Tue Apr 24 2001 dmeszar@suse.cz
- sound fonts loading temporarily removed
* Tue Apr 24 2001 ro@suse.de
- fixed time-stamps in tar
* Tue Apr 24 2001 dmeszar@suse.cz
- 'install sndfonts' button in summary dialog
* Mon Apr 23 2001 dmeszar@suse.cz
- multiple sound cards installation fixed, volume settings fixed
- fonts loading feature for soundblaster
* Tue Apr 17 2001 dmeszar@suse.cz
- autodocs build fixed
* Tue Apr 17 2001 dmeszar@suse.cz
- sound summary module added, fixed 'requires'
* Fri Mar 30 2001 dmeszar@suse.cz
- options editing, quick config
* Sat Mar 17 2001 dan@suse.cz
- ycpdoc removed from requires
* Wed Mar  7 2001 dan@suse.cz
- package rename
* Thu Jan 25 2001 dan@suse.cz
- y2log fixes
* Mon Jan 22 2001 dan@suse.cz
- another locale fix
* Mon Jan 22 2001 dan@suse.cz
- locale problem for displaying all cards fixed
* Thu Jan 18 2001 dan@suse.cz
- options passing fix (bug 5855)
* Fri Jan 12 2001 kkaempf@suse.de
- bump version for latest fixes
* Fri Jan 12 2001 dan@suse.de
- dialog sequence for one card fix
* Wed Jan 10 2001 dan@suse.cz
- don't call complex dialog when just one sound card is beeing installed
- log fixes
* Tue Jan  9 2001 dan@suse.cz
- fix playing sound sample on background (bug #5263)
* Fri Jan  5 2001 kkaempf@suse.de
- fix frame caption for gettext
* Thu Jan  4 2001 dan@suse.cz
- special warning dialog for nm256 cards
* Fri Dec 15 2000 dan@suse.cz
- skip/back button sequence fixed (bug #4679)
* Wed Dec 13 2000 mike@suse.de
- new menuentry file
* Tue Dec 12 2000 kkaempf@suse.de
- use tmpdir instead of /tmp
* Sat Dec  9 2000 dan@suse.cz
- options exist test, disabling sound table omitted
* Fri Dec  8 2000 dan@suse.cz
- spec file fix
* Fri Dec  8 2000 kendy@suse.cz
- All /sbin/init.d changed to /etc/init.d
* Thu Dec  7 2000 arvin@suse.de
- call sound (not lan) in menu
* Thu Dec  7 2000 arvin@suse.de
- fix double quoted symbol
* Thu Dec  7 2000 dan@suse.cz
- y2d_snd is required, amixer call differ for more cards
* Wed Dec  6 2000 kkaempf@suse.de
- adapt to new alsa package
  support multiple cards
  pack sources with bzip2
* Fri Sep 29 2000 kkaempf@suse.de
- do MacRISC dmasound right
  version 2.0.13
* Wed Sep 27 2000 dan@suse.cz
- PPC hack added
* Mon Sep 18 2000 dan@suse.cz
- exception for ppc hardcoded
* Thu Jul 13 2000 dan@suse.de
- minor fixes ('\n' added, etc.)
* Tue Jul 11 2000 dan@suse.de
- fixed writing of modules.conf (last line)
* Tue Jul  4 2000 dan@suse.de
- fixed aplay calling
* Mon Jul  3 2000 kkaempf@suse.de
- changed test sound in alsa package
  version 2.0.7
* Thu Jun 29 2000 kkaempf@suse.de
- requires y2t_snd
* Tue Jun 27 2000 dan@suse.de
- more comments for translators
* Mon Jun 26 2000 kkaempf@suse.de
- message fixes
  version 2.0.5
* Fri Jun 23 2000 dan@suse.de
- comments for translators added
* Wed Jun 21 2000 dan@suse.de
- messages correction
* Tue Jun 20 2000 dan@suse.de
- fixed volume setting
* Fri Jun 16 2000 dan@suse.de
- minor layout changes
* Fri May 19 2000 kkaempf@suse.de
- initial version
